pub enum TreeChildren<'a, Id> {
Leaf,
Unloaded,
Loading,
Loaded(&'a [Id]),
}Expand description
The state of a node’s child list.
Unlike an empty slice, Unloaded and Loading preserve the fact that a node is a branch
whose children may be loaded asynchronously.
Variants
Leaf
The node is known to be a leaf.
Unloaded
Children exist or may exist, but have not been loaded yet.
Loading
Children are currently loading.
Loaded(&'a [Id])
Children are loaded and exposed as a stable slice.
Implementations
Sourceimpl<'a, Id> TreeChildren<'a, Id>
impl<'a, Id> TreeChildren<'a, Id>