pub struct TreeRevision(/* private fields */);Expand description
A monotonically increasing revision of model, filter, or sorting data.
The projection cache is rebuilt whenever any participating revision changes. A
TreeModel implementation must return a new value after changing its contents.
Implementations
Sourceimpl TreeRevision
impl TreeRevision