pub struct TreeQuery<F = NoFilter, S = NoSort> { /* private fields */ }Expand description
A complete query for building the visible projection.
Implementations
Sourceimpl<F, S> TreeQuery<F, S>
impl<F, S> TreeQuery<F, S>
Sourcepub fn with_filter<NF>(
self,
filter: NF,
config: TreeFilterConfig,
revision: TreeRevision,
) -> TreeQuery<NF, S>
pub fn with_filter<NF>( self, filter: NF, config: TreeFilterConfig, revision: TreeRevision, ) -> TreeQuery<NF, S>
Sets the filter and its current revision.
Sourcepub fn with_sort<NS>(self, sort: NS, revision: TreeRevision) -> TreeQuery<F, NS>
pub fn with_sort<NS>(self, sort: NS, revision: TreeRevision) -> TreeQuery<F, NS>
Sets the sorting policy and its current revision.
Sourcepub const fn with_filter_config(self, config: TreeFilterConfig) -> Self
pub const fn with_filter_config(self, config: TreeFilterConfig) -> Self
Sets the filtering mode while preserving the filter itself.
Sourcepub const fn with_root_visibility(self, visibility: TreeRootVisibility) -> Self
pub const fn with_root_visibility(self, visibility: TreeRootVisibility) -> Self
Sets how roots are displayed.
Sourcepub const fn with_selection_fallback(
self,
fallback: TreeSelectionFallback,
) -> Self
pub const fn with_selection_fallback( self, fallback: TreeSelectionFallback, ) -> Self
Sets the selection fallback policy.
Sourcepub const fn filter_mut(&mut self) -> &mut F
pub const fn filter_mut(&mut self) -> &mut F
Returns the mutable filter and automatically advances its revision.
Sourcepub const fn sort_mut(&mut self) -> &mut S
pub const fn sort_mut(&mut self) -> &mut S
Returns the mutable sorting policy and automatically advances its revision.
Sourcepub const fn touch_filter(&mut self)
pub const fn touch_filter(&mut self)
Explicitly advances the filter revision, for example after captured data changes.
Sourcepub const fn touch_sort(&mut self)
pub const fn touch_sort(&mut self)
Explicitly advances the sort revision, for example after captured data changes.
Sourcepub fn set_filter_config(&mut self, config: TreeFilterConfig) -> bool
pub fn set_filter_config(&mut self, config: TreeFilterConfig) -> bool
Changes the filtering mode while preserving the filter itself.
Sourcepub fn set_root_visibility(&mut self, visibility: TreeRootVisibility) -> bool
pub fn set_root_visibility(&mut self, visibility: TreeRootVisibility) -> bool
Changes how roots are displayed.
Sourcepub fn set_selection_fallback(
&mut self,
fallback: TreeSelectionFallback,
) -> bool
pub fn set_selection_fallback( &mut self, fallback: TreeSelectionFallback, ) -> bool
Changes the selection fallback policy.
Sourcepub const fn filter_config(&self) -> TreeFilterConfig
pub const fn filter_config(&self) -> TreeFilterConfig
Returns the current filtering mode.
Sourcepub const fn root_visibility(&self) -> TreeRootVisibility
pub const fn root_visibility(&self) -> TreeRootVisibility
Returns the current root display mode.
Sourcepub const fn selection_fallback(&self) -> TreeSelectionFallback
pub const fn selection_fallback(&self) -> TreeSelectionFallback
Returns the current selection fallback policy.
Sourcepub const fn filter_revision(&self) -> TreeRevision
pub const fn filter_revision(&self) -> TreeRevision
Returns the current filter-data revision.
Sourcepub const fn sort_revision(&self) -> TreeRevision
pub const fn sort_revision(&self) -> TreeRevision
Returns the current sort-data revision.